# PulpFileClient::AcsFileApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](AcsFileApi.md#create) | **POST** /pulp/api/v3/acs/file/file/ | Create a file alternate content source
[**delete**](AcsFileApi.md#delete) | **DELETE** {file_file_alternate_content_source_href} | Delete a file alternate content source
[**list**](AcsFileApi.md#list) | **GET** /pulp/api/v3/acs/file/file/ | List file alternate content sources
[**partial_update**](AcsFileApi.md#partial_update) | **PATCH** {file_file_alternate_content_source_href} | Update a file alternate content source
[**read**](AcsFileApi.md#read) | **GET** {file_file_alternate_content_source_href} | Inspect a file alternate content source
[**refresh**](AcsFileApi.md#refresh) | **POST** {file_file_alternate_content_source_href}refresh/ | 
[**update**](AcsFileApi.md#update) | **PUT** {file_file_alternate_content_source_href} | Update a file alternate content source



## create

> FileFileAlternateContentSourceResponse create(file_file_alternate_content_source)

Create a file alternate content source

Alternate Content Source ViewSet for File  ACS support is provided as a tech preview in pulp_file.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::AcsFileApi.new
file_file_alternate_content_source = PulpFileClient::FileFileAlternateContentSource.new # FileFileAlternateContentSource | 

begin
  #Create a file alternate content source
  result = api_instance.create(file_file_alternate_content_source)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling AcsFileApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_alternate_content_source** | [**FileFileAlternateContentSource**](FileFileAlternateContentSource.md)|  | 

### Return type

[**FileFileAlternateContentSourceResponse**](FileFileAlternateContentSourceResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(file_file_alternate_content_source_href)

Delete a file alternate content source

Trigger an asynchronous delete ACS task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::AcsFileApi.new
file_file_alternate_content_source_href = 'file_file_alternate_content_source_href_example' # String | 

begin
  #Delete a file alternate content source
  result = api_instance.delete(file_file_alternate_content_source_href)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling AcsFileApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_alternate_content_source_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedfileFileAlternateContentSourceResponseList list(opts)

List file alternate content sources

Alternate Content Source ViewSet for File  ACS support is provided as a tech preview in pulp_file.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::AcsFileApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List file alternate content sources
  result = api_instance.list(opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling AcsFileApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedfileFileAlternateContentSourceResponseList**](PaginatedfileFileAlternateContentSourceResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(file_file_alternate_content_source_href, patchedfile_file_alternate_content_source)

Update a file alternate content source

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::AcsFileApi.new
file_file_alternate_content_source_href = 'file_file_alternate_content_source_href_example' # String | 
patchedfile_file_alternate_content_source = PulpFileClient::PatchedfileFileAlternateContentSource.new # PatchedfileFileAlternateContentSource | 

begin
  #Update a file alternate content source
  result = api_instance.partial_update(file_file_alternate_content_source_href, patchedfile_file_alternate_content_source)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling AcsFileApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_alternate_content_source_href** | **String**|  | 
 **patchedfile_file_alternate_content_source** | [**PatchedfileFileAlternateContentSource**](PatchedfileFileAlternateContentSource.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> FileFileAlternateContentSourceResponse read(file_file_alternate_content_source_href, opts)

Inspect a file alternate content source

Alternate Content Source ViewSet for File  ACS support is provided as a tech preview in pulp_file.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::AcsFileApi.new
file_file_alternate_content_source_href = 'file_file_alternate_content_source_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a file alternate content source
  result = api_instance.read(file_file_alternate_content_source_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling AcsFileApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_alternate_content_source_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**FileFileAlternateContentSourceResponse**](FileFileAlternateContentSourceResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## refresh

> TaskGroupOperationResponse refresh(file_file_alternate_content_source_href, file_file_alternate_content_source)



Trigger an asynchronous task to create Alternate Content Source content.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::AcsFileApi.new
file_file_alternate_content_source_href = 'file_file_alternate_content_source_href_example' # String | 
file_file_alternate_content_source = PulpFileClient::FileFileAlternateContentSource.new # FileFileAlternateContentSource | 

begin
  result = api_instance.refresh(file_file_alternate_content_source_href, file_file_alternate_content_source)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling AcsFileApi->refresh: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_alternate_content_source_href** | **String**|  | 
 **file_file_alternate_content_source** | [**FileFileAlternateContentSource**](FileFileAlternateContentSource.md)|  | 

### Return type

[**TaskGroupOperationResponse**](TaskGroupOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> AsyncOperationResponse update(file_file_alternate_content_source_href, file_file_alternate_content_source)

Update a file alternate content source

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::AcsFileApi.new
file_file_alternate_content_source_href = 'file_file_alternate_content_source_href_example' # String | 
file_file_alternate_content_source = PulpFileClient::FileFileAlternateContentSource.new # FileFileAlternateContentSource | 

begin
  #Update a file alternate content source
  result = api_instance.update(file_file_alternate_content_source_href, file_file_alternate_content_source)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling AcsFileApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_alternate_content_source_href** | **String**|  | 
 **file_file_alternate_content_source** | [**FileFileAlternateContentSource**](FileFileAlternateContentSource.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

